@@ -8,7 +8,7 @@ class VersionManager(object):
 
     # m_pkg_name = 'pandas-coder'
     m_pkg_name = 'pdcoder'
-    m_current_version = tuple('0.3.7'.split('.'))
+    m_current_version = tuple('0.3.8'.split('.'))
     m_version_re = re.compile(r'\((from versions: (.*?))\)')
 
     def has_updated(self) -> bool:
@@ -32,7 +32,7 @@ class VersionManager(object):
         os.system(
             'pip install pdcoder -U  && python main.py')
 
-        sys.exit()
+        # sys.exit()
 
     def _use_pip(self, cmds: List[str]):
         # cmds = ['pip'] + cmds + ['-i', 'https://pypi.douban.com/simple/']
